==> tutti-ichtyometer-3.1-sources.jar: fr/ifremer/tutti/ichtyometer/RemoteDeviceServiceNotFoundException.java <==
package fr.ifremer.tutti.ichtyometer;

/*
 * #%L
 * Tutti :: Ichtyometer API
 * $Id: RemoteDeviceServiceNotFoundException.java 1529 2014-01-28 18:37:06Z tchemit $
 * $HeadURL:$
 * %%
 * Copyright (C) 2012 - 2014 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import java.io.IOException;

/**
 * If remote device service is not found.
 * <p/>
 * Created on 1/27/14.
 *
 * @author Tony Chemit <chemit@codelutin.com>
 * @since 3.1
 */
public class RemoteDeviceServiceNotFoundException extends IOException {

    private static final long serialVersionUID = 1L;

    public RemoteDeviceServiceNotFoundException(String message) {
        super(message);
    }

    public RemoteDeviceServiceNotFoundException(String message, Throwable cause) {
        super(message, cause);
    }

    public RemoteDeviceServiceNotFoundException(Throwable cause) {
        super(cause);
    }
}

==> tutti-ichtyometer-3.1.2-sources.jar: fr/ifremer/tutti/ichtyometer/RemoteDeviceServiceNotFoundException.java <==
package fr.ifremer.tutti.ichtyometer;

/*
 * #%L
 * Tutti :: Ichtyometer API
 * $Id: RemoteDeviceServiceNotFoundException.java 1573 2014-02-04 16:41:40Z tchemit $
 * $HeadURL: https://forge.codelutin.com/svn/tutti/tags/tutti-3.1.2/tutti-ichtyometer/src/main/java/fr/ifremer/tutti/ichtyometer/RemoteDeviceServiceNotFoundException.java $
 * %%
 * Copyright (C) 2012 - 2014 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import java.io.IOException;

/**
 * If remote device service is not found.
 * <p/>
 * Created on 1/27/14.
 *
 * @author Tony Chemit <chemit@codelutin.com>
 * @since 3.1
 */
public class RemoteDeviceServiceNotFoundException extends IOException {

    private static final long serialVersionUID = 1L;

    public RemoteDeviceServiceNotFoundException(String message) {
        super(message);
    }

    public RemoteDeviceServiceNotFoundException(String message, Throwable cause) {
        super(message, cause);
    }

    public RemoteDeviceServiceNotFoundException(Throwable cause) {
        super(cause);
    }
}
